/* alan.c - Created by venum 4.2 beta */

#include "alan.version.h"

Product alan = {
  "Alan",
  "Adventure Language System",
  "Alan 3.0alpha8",
  "Alan 3.0alpha8 -- Adventure Language System (2010-09-19 18:16)",
  "2010-09-19",
  "18:16:06",
  "Thomas",
  "",
  "cygwin32",
  {"3.0alpha8", 3, 0, 8, 1284912966, "alpha"}
};

static char *alanId =
  "@(#)RELEASE ";
